# @upleveled/babel-plugin-remove-node-prefix

A Babel plugin to remove [the `node:` schema prefix for builtin (core) modules first introduced in Node.js v16](https://twitter.com/jasnell/status/1385238402149150721).

This may be useful for transpiling modern code to environments with older versions of Node.js.

## Example

**In**

```js
import fs from 'node:fs';
const url = require('node:url');
```

**Out**

```js
import fs from 'fs';
const url = require('url');
```

## Installation

```sh
yarn add --dev @upleveled/babel-plugin-remove-node-prefix
```

Or, use npm:

```sh
npm install @upleveled/babel-plugin-remove-node-prefix --save-dev
```

## Usage

### Via `babel.config.js` (Recommended)

**babel.config.js**

```js
// without options
module.exports = {
  plugins: ['@upleveled/remove-node-prefix'],
};
```

### Via CLI

```sh
babel --plugins @upleveled/remove-node-prefix script.js
```

### Via Node API

```javascript
require('@babel/core').transform('code', {
  plugins: ['@upleveled/remove-node-prefix'],
});
```
